@@ -37,6 +37,8 @@
 #include <io.h>
 #endif
 
+#include <cstring>
+#include <cstdlib>
 #include <cerrno>
 #include <cassert>
 
