@@ -1077,7 +1077,7 @@ bool centerim::sendevent(const imevent &ev, icqface::eventviewresult r) {
 
 	if(proceed) {
 	    if(r == icqface::forward)
-		sendev->setcontact(imcontact());
+		sendev->setcontact(*(face.muins.begin()));
 
 	    if(proceed = face.eventedit(*sendev))
 	    if(proceed = !sendev->empty()) {
@@ -1620,7 +1620,7 @@ void centerim::exectimers() {
 							face.log(_("+ Set N/A after screen detach"));
 					} else { /* Screen is attached */
 						/* The user attached the screen */
-						if (autostat[notavail] == true) {
+						if ((autostat[notavail] == true) && (toset != notavail)) {
 							toset = available;
 						}
 					}
