@@ -33,6 +33,7 @@
 #include "ljhook.h"
 #include "gaduhook.h"
 #include "msnhook.h"
+#include "icqcontacts.h"
 
 #include "icqface.h"
 
@@ -40,6 +41,8 @@
 
 #include <time.h>
 
+#define NOTIFBUF 512
+
 time_t timer_current = time(0);
 
 abstracthook::abstracthook(protocolname aproto)
@@ -243,6 +246,7 @@ string abstracthook::rusconv(const string &tdir, const string &text) {
     if(tdir == "wk") r = siconv(text, conf.getconvertfrom(proto), conf.getconvertto(proto)); else
     if(tdir == "ku") r = siconv(text, conf.getconvertto(proto), "utf-8"); else
     if(tdir == "uk") r = siconv(text, "utf-8", conf.getconvertto(proto)); else
+    if(tdir == "ck") r = siconv(text, "UCS-2BE", conf.getconvertto(proto)); else
 #endif
 	r = text;
 
@@ -302,8 +306,8 @@ string abstracthook::getmd5(const string &text) {
     md5_finish(&state, digest);
 
     for(int i = 0; i < 16; i++) {
-	sprintf(buf, "%02x", digest[i]);
-	r += buf;
+        sprintf(buf, "%02x", digest[i]);
+        r += buf;
     }
 
     return r;
@@ -342,7 +346,7 @@ bool abstracthook::regattempt(unsigned int &auin, const string &apassword, const
 
 void abstracthook::log(logevent ev, ...) {
     va_list ap;
-    char buf[512];
+    char buf[NOTIFBUF];
     static map<logevent, string> lst;
 
     if(lst.empty()) {
@@ -357,7 +361,7 @@ void abstracthook::log(logevent ev, ...) {
     }
 
     va_start(ap, ev);
-    vsprintf(buf, lst[ev].c_str(), ap);
+    vsnprintf(buf, NOTIFBUF, lst[ev].c_str(), ap);
     va_end(ap);
 
     face.log((string) "+ [" + conf.getprotocolname(proto)  + "] " + buf);
@@ -755,7 +759,7 @@ string abstracthook::getTimezoneIDtoString(signed char id) {
 	return "Unspecified";
     } else {
 	char buf[32];
-	sprintf(buf, "GMT %s%d:%s", id > 0 ? "-" : "+", abs(id/2), id % 2 == 0 ? "00" : "30");
+	snprintf(buf, sizeof(buf), "GMT %s%d:%s", id > 0 ? "-" : "+", abs(id/2), id % 2 == 0 ? "00" : "30");
 	return buf;
     }
 }
