@@ -30,6 +30,7 @@
 #include "gaduhook.h"
 #include "icqface.h"
 #include "imlogger.h"
+#include "icqcontacts.h"
 
 #include "libgadu-config.h"
 #include "libgadu.h"
@@ -37,6 +38,7 @@
 #include <netdb.h>
 #include <arpa/inet.h>
 #include <netinet/in.h>
+#include <limits.h>
 
 #ifdef HAVE_JPEGLIB_H
 extern "C" {
@@ -85,6 +87,7 @@ static int imstatus2gg(imstatus st, const string &desc = "") {
 	case dontdisturb:
 	case occupied:
 	case notavail:
+	case outforlunch:
 	case away:
 	    gst = desc.empty() ?
 		GG_STATUS_BUSY : GG_STATUS_BUSY_DESCR;
@@ -912,14 +915,15 @@ string gaduhook::handletoken(struct gg_http *h) {
 
     do {
 	while (tmpfilep == NULL) {
-	    char tmpnam[100];
+	    char tmpnam[PATH_MAX];
 	    int tmpfiledes;
-	    if (getenv("TMPDIR") && strlen(getenv("TMPDIR")) < 50) {
-		sprintf (tmpnam, "%s/gg.token.XXXXXX", getenv("TMPDIR"));
-	    } else {
-		sprintf (tmpnam, "/tmp/gg.token.XXXXXX");
-	    }
-	    
+	    char * tmpdir = getenv("TMPDIR");
+
+	    if (!tmpdir)
+		tmpdir = "/tmp";
+
+	    snprintf(tmpnam, sizeof(tmpnam), "%s/gg.token.XXXXXX", tmpnam);
+
 	    if ((tmpfiledes = mkstemp (tmpnam)) == -1) {
 		tmpfilep = NULL;
 	    } else {
