@@ -22,6 +22,7 @@ class jabberhook: public abstracthook {
 	map<string, string> roster;
 	map<string, string> awaymsgs;
 	map<string, vector<string> > chatmembers;
+	map<string, map<string, pair<char, imstatus> > > statuses;  // <JID, <resource, <prio, status> > >
 
 	struct agent {
 	    string jid, name, desc;
@@ -54,6 +55,8 @@ class jabberhook: public abstracthook {
 
 	vector<agent> agents;
 
+	imstatus process_presence(string id, string s, char prio, imstatus ust);
+
 	static void statehandler(jconn conn, int state);
 	static void packethandler(jconn conn, jpacket packet);
 	static void jlogger(jconn conn, int inout, const char *p);
