@@ -129,6 +129,8 @@ void yahoohook::init() {
     c.ext_yahoo_webcam_viewer = &webcam_viewer;
     c.ext_yahoo_webcam_data_request = &webcam_data_request;
     c.ext_yahoo_got_search_result = &got_search_result;
+    c.ext_yahoo_got_auth_request = &auth_request;
+    c.ext_yahoo_got_auth_response = &auth_response;
     c.ext_yahoo_log = &ylog;
 
     yahoo_register_callbacks(&c);
@@ -322,10 +324,24 @@ bool yahoohook::send(const imevent &ev) {
 	    }
 
 	    return true;
+	} else if (ev.gettype() == imevent::authorization) {
+		const imauthorization *m = static_cast<const imauthorization *> (&ev);
+		
+		switch(m->getauthtype()) {
+			case imauthorization::Granted:
+				yahoo_auth_grant(cid, ev.getcontact().nickname.c_str());
+				break;
+
+			case imauthorization::Rejected:
+				yahoo_auth_deny(cid, ev.getcontact().nickname.c_str());
+				break;
+		}
+		
+		return true;
 	}
 
 	if(!ischannel(c)) {
-	    yahoo_send_im(cid, 0, ev.getcontact().nickname.c_str(), text.c_str(), 0);
+	    yahoo_send_im(cid, 0, ev.getcontact().nickname.c_str(), text.c_str(), 0, 0);
 	} else {
 	    yahoo_conference_message(cid, 0, getmembers(ev.getcontact().nickname.substr(1)),
 		ev.getcontact().nickname.c_str()+1, text.c_str(), 0);
@@ -365,9 +381,12 @@ void yahoohook::sendnewuser(const imcontact &ic, bool report) {
 
 	    if(!found) {
 		if(report) log(logContactAdd, ic.nickname.c_str());
+		if (groups.size()>0)
+		{
 		vector<icqgroup>::const_iterator ig = find(groups.begin(), groups.end(), clist.get(ic)->getgroupid());
-		if(ig != groups.end()) {
-		    yahoo_add_buddy(cid, ic.nickname.c_str(), ig->getname().c_str(), "");
+		if (ig == groups.end())
+			ig = groups.begin();
+	    yahoo_add_buddy(cid, ic.nickname.c_str(), ig->getname().c_str(), "");
 		}
 	    }
 	}
@@ -764,7 +783,7 @@ void yahoohook::got_buddies(int id, YList *buds) {
 void yahoohook::got_identities(int id, YList *buds) {
 }
 
-void yahoohook::status_changed(int id, char *who, int stat, char *msg, int away) {
+void yahoohook::status_changed(int id, char *who, int stat, char *msg, int away, int idle, int mobile) {
     yhook.userstatus(who, stat, msg ? msg : "", (bool) away);
 }
 
@@ -1101,7 +1120,7 @@ void yahoohook::connect_complete(void *data, int source) {
 	ccd->callback(source, so_error, ccd->callback_data);
     }
 
-    free(ccd);
+    delete ccd;
 }
 
 void yahoohook::got_ignore(int id, YList * igns) {
@@ -1146,6 +1165,39 @@ void yahoohook::webcam_viewer(int id, char *who, int connect) {
 void yahoohook::webcam_data_request(int id, int send) {
 }
 
+void yahoohook::auth_request(int id, char *who, char *msg) {
+    imcontact ic(who, yahoo);
+    string text = cuthtml(msg?msg: "", chCutBR | chLeaveLinks);
+
+    yhook.checkinlist(ic);
+    text = yhook.decode(text, true);
+
+	em.store(imauthorization(ic, imevent::incoming, imauthorization::Request, text));
+}
+
+void yahoohook::auth_response(int id, const char *who, char granted, const char *msg) {
+    imcontact ic(who, yahoo);
+    string text = cuthtml(msg?msg:"", chCutBR | chLeaveLinks);
+
+    //yhook.checkinlist(ic);
+    text = yhook.decode(text, true);
+	string message;
+	if (granted)
+		message = "The user has accepted your authorization request";
+	else
+	{
+		message = "The user has rejected your authorization request";
+		if (!text.empty())
+		{
+			message += " (";
+			message += text;
+			message += ")";
+		}
+	}
+
+	em.store(imnotification(ic, message));
+}
+
 int yahoohook::ylog(char *fmt, ...) {
     if(conf.getdebug()) {
 	char buf[NOTIFBUF];
