@@ -27,7 +27,7 @@
 #include <dirent.h>
 #include <fstream>
 
-#ifdef __sun__
+#if defined(__sun__) || defined(__NetBSD__)
 #include <sys/statvfs.h>
 #endif
 
@@ -483,6 +483,7 @@ void icqconf::loadmainconfig() {
 	    if(param == "autoaway") autoaway = atol(buf.c_str()); else
 	    if(param == "autona") autona = atol(buf.c_str()); else
 	    if(param == "antispam") antispam = true; else
+	    if(param == "showopenedchats") setshowopenedchats(true); else
 	    if(param == "dropauthreq") dropauthreq = true; else
 	    if(param == "screenna") screenna = true; else
 	    if(param == "screensocketpath") screensocketpath = buf; else
@@ -500,7 +501,7 @@ void icqconf::loadmainconfig() {
 	    if(param == "sort_by_activity") setsortmode(icqconf::sort_by_activity); else
 	    if(param == "sort_by_name") setsortmode(icqconf::sort_by_name); else
 	    if(param == "smtp") setsmtphost(buf); else
-	    if(param == "browser") setbrowser(browser); else
+	    if(param == "browser") setbrowser(buf); else
 	    if(param == "http_proxy") sethttpproxyhost(buf); else
 	    if(param == "log") makelog = true; else
 	    if(param == "proxy_connect") proxyconnect = true; else
@@ -573,7 +574,8 @@ void icqconf::save() {
 	    if(hideoffline) f << "hideoffline" << endl;
 	    if(emacs) f << "emacs" << endl;
 	    if(getquote()) f << "quotemsgs" << endl;
-	    if(getantispam()) f << "antispam" << endl;
+        if(getantispam()) f << "antispam" << endl;
+        if(getshowopenedchats()) f << "showopenedchats" << endl;
 	    if(getdropauthreq()) f << "dropauthreq" << endl;
 	    if(getusingcaptcha()) f << "captcha" << endl;
 	    if(getmailcheck()) f << "mailcheck" << endl;
@@ -701,6 +703,7 @@ void icqconf::loadcolors() {
 	    schemer.push(cp_clist_free_for_chat, "clist_free_for_chat   green/transparent   bold");
 	    schemer.push(cp_clist_invisible, "clist_invisible   grey/transparent   bold");
 	    schemer.push(cp_clist_not_in_list, "clist_not_in_list   white/transparent   bold");
+	    schemer.push(cp_clist_unread, "clist_unread red/transparent	bold");
 	    break;
 
 	case rcblue:
@@ -735,6 +738,7 @@ void icqconf::loadcolors() {
 	    schemer.push(cp_clist_free_for_chat, "clist_free_for_chat   green/transparent   bold");
 	    schemer.push(cp_clist_invisible, "clist_invisible   grey/transparent   bold");
 	    schemer.push(cp_clist_not_in_list, "clist_not_in_list   white/transparent   bold");
+	    schemer.push(cp_clist_unread, "clist_unread black/blue	bold");
 	    break;
     }
 
@@ -890,7 +894,7 @@ void icqconf::loadactions() {
 	    of << "openurl \\" << endl;
 	    of << "    (if test ! -z \"`ps x | grep /" << browser << " | grep -v grep`\"; \\" << endl;
 	    of << "\tthen DISPLAY=0:0 " << browser << " -remote 'openURL($url$, new-window)'; \\" << endl;
-	    of << "\telse DISPLAY=0:0 " << browser << " \"$url$\"; \\" << endl;
+	    of << "\telse DISPLAY=0:0 " << browser << " '$url$'; \\" << endl;
 	    of << "    fi) >/dev/null 2>&1 &" << endl;
 
 	    of << "detectmusic \\" << endl;
@@ -1106,6 +1110,11 @@ void icqconf::setantispam(bool fas) {
     antispam = fas;
 }
 
+void icqconf::setshowopenedchats(bool fsoc)
+{
+    showopenedchats = fsoc;
+}
+
 void icqconf::setdropauthreq(bool fas) {
     dropauthreq = fas;
 }
@@ -1168,8 +1177,21 @@ string icqconf::execaction(const string &name, const string &param) {
     char ch;
 
     if(name == "openurl")
-    while((npos = torun.find("$url$")) != -1)
-	torun.replace(npos, 5, param);
+    {
+	string url = param;
+	int pos = 0, fnd = -1;
+	
+	char enc[4];
+	
+	while( ((fnd = url.find("'", pos)) != -1) || ((fnd = url.find("\"", pos)) != -1) ) {
+		snprintf(enc, 4, "%%%02X", url[fnd]);
+	    url.replace(fnd, 1, enc);
+    	pos = fnd+3;
+	}
+	
+	while((npos = torun.find("$url$")) != -1)
+	    torun.replace(npos, 5, url);
+    }
 
     if(!pipe(inpipe) && !pipe(outpipe)) {
 	memset(&sact, 0, sizeof(sact));
@@ -1211,7 +1233,6 @@ string icqconf::execaction(const string &name, const string &param) {
 
 	sigaction(SIGCHLD, &osact, 0);
     }
-
     face.log(_("+ launched the %s action command"), name.c_str());
     return out;
 }
@@ -1546,7 +1567,7 @@ void icqconf::externalstatuschange(char st, const string &proto) const {
 void icqconf::usage() const {
 	cout << PACKAGE << " " << centerim::version << endl;
 	
-    cout << endl << _("Usage: ") << argv0 << " [OPTION].." << endl;
+    cout << endl << _("Usage: ") << argv0 << _(" [OPTION]...") << endl;
 	
     cout << endl << _("General options:") << endl;
     cout << _("  --ascii, -a              use ASCII characters for windows and UI controls") << endl;
@@ -1566,7 +1587,7 @@ void icqconf::usage() const {
     cout << _("  -t, --to <destination>   destination UIN or nick (depends on protocol)") << endl;
     cout << _("  -n, --number <phone#>    mobile number to send an event to (sms only)") << endl;
 
-    cout << endl << _("Report bugs to http://sourceforge.net/projects/centerim.") << endl;
+    cout << endl << _("Report bugs to http://bugzilla.centerim.org/.") << endl;
 }
 
 void icqconf::setproxy() {
@@ -1714,7 +1735,7 @@ string icqconf::gethttpproxypasswd() const {
 void icqconf::checkdiskspace() {
     fenoughdiskspace = true;
 
-#ifndef __sun__
+#if !(defined(__sun__) || defined(__NetBSD__))
     struct statfs st;
     if(!statfs(conf.getdirname().c_str(), &st)) {
 #else
