@@ -50,7 +50,8 @@ enum cicq_colorpairs {
     cp_clist_occupied,
     cp_clist_free_for_chat,
     cp_clist_invisible,
-    cp_clist_not_in_list
+    cp_clist_not_in_list,
+    cp_clist_unread,
 };
 
 enum cicq_keybindings {
@@ -155,7 +156,8 @@ class icqconf {
 	bool hideoffline, quote, savepwd, antispam, screenna, mailcheck,
 	    makelog, fenoughdiskspace, askaway, bidi, logtimestamps,
 	    logonline, emacs, proxyconnect, proxyssl, notitles, debug,
-	    timestampstothesecond, dropauthreq, usingcaptcha, askquit;
+        timestampstothesecond, dropauthreq, usingcaptcha, askquit,
+        showopenedchats;
 
 	unsigned int captchatimeout;
 
@@ -330,6 +332,9 @@ class icqconf {
 	void getpeertopeer(int &min, int &max) const { min = ptpmin; max = ptpmax; }
 	void setpeertopeer(int min, int max) { ptpmin = min; ptpmax = max; }
 
+	bool getshowopenedchats() const { return showopenedchats; }
+	void setshowopenedchats(bool fsoc);
+
 	string execaction(const string &action, const string &param = "");
 
 	imstatus getstatus(protocolname pname);
