@@ -1119,6 +1119,7 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
     bool savepwd = conf.getsavepwd();
     bool hideoffl = conf.gethideoffline();
     bool antispam = conf.getantispam();
+    bool showopenedchats = conf.getshowopenedchats();
     bool dropauthreq = conf.getdropauthreq();
     bool usingcaptcha = conf.getusingcaptcha();
     bool mailcheck = conf.getmailcheck();
@@ -1151,6 +1152,7 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
     convlanguages.push_back(_("None"));
     convlanguages.push_back(_("Russian"));
     convlanguages.push_back(_("Polish"));
+    convlanguages.push_back(_("German UTF-8"));
     vector<string>::const_iterator iconvlang = convlanguages.begin();
 
     string convertfrom = conf.getconvertfrom();
@@ -1208,6 +1210,7 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 	t.addleaff(i, 0, 32, _(" Left panel width :  %d "), conf.getleftpanelwidth());
 	t.addleaff(i, 0, 33, _(" Log panel height :  %d "), conf.getlogpanelheight());
 	t.addleaff(i, 0, 34, _(" Chat panel height : %d "), conf.getchatpanelheight());
+    t.addleaff(i, 0, 55, _(" Show opened chats : %s "), stryesno(showopenedchats));
 
     #ifdef USE_FRIBIDI
 	t.addleaff(i, 0, 20, _( " Enable bidirectional languages support : %s "), stryesno(bidi));
@@ -1233,7 +1236,7 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 	i = t.addnode(_(" Contact list "));
 	t.addleaff(i, 0, 17, _(" Arrange contacts into groups : %s "), strgroupmode(gmode));
 	t.addleaff(i, 0, 54, _(" Sort contacts by : %s "), strsortmode(smode));
-	t.addleaff(i, 0,  6, _(" Hide offline users : %s "), stryesno(hideoffl));
+    t.addleaff(i, 0,  6, _(" Hide offline users : %s "), stryesno(hideoffl));
 	t.addleaff(i, 0, 14, _(" Anti-spam: kill msgs from users not on the list : %s "), stryesno(antispam));
 	t.addleaff(i, 0, 51, _(" Anti-spam: ignore authorization requests: %s "), stryesno(dropauthreq));
 	t.addleaff(i, 0, 52, _(" Anti-spam: use captcha to identify bots: %s "), stryesno(usingcaptcha));
@@ -1401,6 +1404,12 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 				convertto = "iso-8859-2";
 				multichange(conv, true);
 				break;
+
+			    case 3:
+				convertfrom = "iso-8859-15";
+				convertto = "utf-8";
+				multichange(conv, true);
+				break;
 			}
 			break;
 		    case 27:
@@ -1469,7 +1478,9 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 			    smode == icqconf::sort_by_status_and_name ? icqconf::sort_by_activity :
 			    smode == icqconf::sort_by_activity ? icqconf::sort_by_name :
 				icqconf::sort_by_status_and_activity;
-			break;
+            break;
+            case 55: showopenedchats = !showopenedchats; break;
+                
   		}
   		break;
 	    case 1:
@@ -1482,6 +1493,7 @@ bool icqface::updateconf(icqconf::regsound &s, icqconf::regcolor &c) {
 		conf.sethideoffline(hideoffl);
 		conf.setemacs(emacs);
 		conf.setantispam(antispam);
+		conf.setshowopenedchats(showopenedchats);
 		conf.setdropauthreq(dropauthreq);
 		conf.setusingcaptcha(usingcaptcha);
 		conf.setmailcheck(mailcheck);
@@ -1626,10 +1638,10 @@ void icqface::detailsidle(dialogbox &db) {
     icqcontact *c;
 
     if(!face.detailsfetched)
-    if(c == clist.get(contactroot))
-		if(c->updated()) {
-			face.gendetails(db.gettree());
-			db.gettree()->redraw();
+    if(c = clist.get(contactroot))
+	if(c->updated()) {
+		face.gendetails(db.gettree());
+		db.gettree()->redraw();
 		face.status(_("Your details have been fetched"));
 		face.detailsfetched = true;
     	}
